@@ -588,7 +588,7 @@ class Project(_NamedObject):
     _ident = "p"
 
     @cached_property
-    def _platform_repo(self) -> str:
+    def _platform_repo(self) -> Tuple[str, str]:
         URL_PREFIXES = self.woc.config["sites"]
         prefix, body = self.key.split("_", 1)
         if prefix == "sourceforge.net":
@@ -837,7 +837,7 @@ class RootProject(Project):
 
     @cached_property
     def commits(self) -> "List[Commit]":
-        return [Commit(c) for c in self._get_list_values(f"{self._ident}2C")]
+        return [Commit(c) for c in self._get_list_values(f"{self._ident}2c")]
 
     @cached_property
     def projects(self) -> "List[Project]":
